# Table of Contents

- [process-modeling-v3](<./process-modeling-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: Process (Meta Model v3)](<./Modeling-Process-Meta-Model-v3.md>)
  - [Fundamentals](<./Modeling-Process-Meta-Model-v3/Fundamentals.md>)
  - [Further options for modeling Processes](<./Modeling-Process-Meta-Model-v3/Further-options-for-modeling-Processes.md>)
